@@ -629,7 +629,7 @@ test_that("Test non-numeric arguments", {
 })
 
 test_that("Errors", {
-  expect_error(window_run(list(1:10), k = 5), "Invalid data type")
+  expect_error(window_run(list(1:10), k = 5), "Invalid \\'x\\' type")
 
   expect_error(window_run(1:10, k = (1:9)), "length of k and length of x differs")
   expect_error(window_run(1:10, k = c(NA, 1:9)), "Function doesn't accept NA values in k vector")
